using System;
using System.Collections;
using System.Net.Http;
using System.Text;
using System.Threading.Tasks;
using BepInEx;
using UnityEngine;

namespace GrafanaPostMod
{
    [BepInPlugin("com.pengucc.grafanapostmod", "Grafana Post Mod", "1.0.1")]
    public class GrafanaPostMod : BaseUnityPlugin
    {
        private static HttpClient httpClient;
        private float postRequestInterval = 15f; // 15 seconds
        private string apiUrl = "https://stats.yourdomain.com/api/players"; // Ensure this is the correct URL

        void Awake()
        {
            Logger.LogInfo("Grafana Post Mod is initializing...");
            httpClient = new HttpClient();
            StartCoroutine(PostRequestCoroutine());
        }

        private IEnumerator PostRequestCoroutine()
        {
            while (true)
            {
                yield return new WaitForSeconds(postRequestInterval);
                StartCoroutine(SendPostRequest());
            }
        }

        private IEnumerator SendPostRequest()
        {
            string jsonData = "{ \"player_count\": 1 }";
            StringContent content = new StringContent(jsonData, Encoding.UTF8, "application/json");
            Task<HttpResponseMessage> requestTask = httpClient.PostAsync(apiUrl, content);
            yield return new WaitUntil(() => requestTask.IsCompleted);

            if (requestTask.Exception != null)
            {
                Logger.LogError($"Error sending POST request: {requestTask.Exception.Message}");
                yield break;
            }

            HttpResponseMessage response = requestTask.Result;
            if (!response.IsSuccessStatusCode)
            {
                Logger.LogError($"Error: Received HTTP {(int)response.StatusCode} {response.ReasonPhrase}");
                yield break;
            }

            Task<string> responseBodyTask = response.Content.ReadAsStringAsync();
            yield return new WaitUntil(() => responseBodyTask.IsCompleted);
            
            Logger.LogInfo($"Successfully sent POST request. Response: {responseBodyTask.Result}");
        }
    }
}
